#-*- encoding: UTF-8 -*-
from setuptools import setup, find_packages
import sys
"""
打包的用的setup必须引入，
"""

VERSION = '0.0.2'

setup(name='danmu.fm',
      version=VERSION,
      description="a tiny and smart cli player of douyutv,ximalayad,anmu based on Python",
      long_description='just enjoy',
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='python douyu danmu danmu.fm terminal',
      author='twocucao',
      author_email='twocucao@gmail.com',
      url='https://github.com/twocucao/doumu.fm',
      license='MIT',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=True,
      install_requires=[
        'requests',
        'pycookiecheat'
      ] + (['pyobjc-core', 'pyobjc'] if 'darwin' in sys.platform else []),
      entry_points={
        'console_scripts':[
            'danmu.fm = danmufm.danmu:main'
        ]
      },
)

